@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::MSCHOUT;
-$Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.32';
+$Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.33';
 # ABSTRACT: Use L<Dist::Zilla> like MSCHOUT does
 
 use Moose;
@@ -113,10 +113,8 @@ sub configure {
     }
 
     $self->add_plugins(
-        qw(
-            Git::Check
-            Git::Commit
-        ),
+        [ 'Git::Check' => { allow_dirty => [qw(.travis.yml)] } ],
+        'Git::Commit',
         [ 'Git::CommitBuild' => { release_branch => $self->release_branch } ],
         [ 'Git::Tag'         => { branch => $self->release_branch } ],
         [
@@ -201,7 +199,7 @@ Dist::Zilla::PluginBundle::MSCHOUT - Use L<Dist::Zilla> like MSCHOUT does
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
@@ -228,6 +226,7 @@ It's equivalent to:
  [NextRelease]
     format = "%-2v  %{yyyy-MM-dd}d"
  [Git::Check]
+ allow_dirty = .travis.yml
  [Git::Commit]
  [Git::NextVersion]
     first_version = 0.01
